@@ -6,7 +6,7 @@ use base qw(Exporter);
 
 our @EXPORT = qw(get_default_browser);
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 sub get_default_browser
 {
@@ -104,6 +104,7 @@ Win32::GetDefaultBrowser - Return full path to default browser on Windows system
 =head1 DESCRIPTION
 
 Returns the full path to the default browser on a Windows system.
+
 Pollutes the namespace with one function: get_default_browser.
 
 =head1 METHODS
@@ -116,13 +117,19 @@ Internet Explorer on failure.
 =head1 Version History
 
 1.00 - Initial Release
-1.01 - Added Windows 10 support (I hope)
 
-=head1 AUTHOR, COPYRIGHT, and LICENSE
+1.01 - Added Windows 10 support (hopefully)
 
-Copyright(C) 2020, phatWares, USA. All rights reserved.
+1.02 - Fixed this POD document
+
+=head1 Author
+
+Brandon Bourret
+
+=head1 License
 
 Permission is granted to use this software under the same terms as Perl itself.
+
 Refer to the L<Perl Artistic|perlartistic> license for details.
 
 =cut
\ No newline at end of file
